# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.subject import Subject  # noqa: E501

class TestSubject(unittest.TestCase):
    """Subject unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Subject:
        """Test Subject
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Subject`
        """
        model = Subject()  # noqa: E501
        if include_optional:
            return Subject(
                name = '',
                auditory = '',
                teacher = '',
                lesson = schedule_service_client.models.lesson.Lesson(
                    topic = 56, 
                    lesson = 56, 
                    type = '', )
            )
        else:
            return Subject(
        )
        """

    def testSubject(self):
        """Test Subject"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.worksheet_settings import WorksheetSettings  # noqa: E501

class TestWorksheetSettings(unittest.TestCase):
    """WorksheetSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorksheetSettings:
        """Test WorksheetSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorksheetSettings`
        """
        model = WorksheetSettings()  # noqa: E501
        if include_optional:
            return WorksheetSettings(
                day_range = ERROR_TO_EXAMPLE_VALUE,
                year_range = ERROR_TO_EXAMPLE_VALUE,
                days_in_week_column_number = None,
                platoon_column_number = None,
                subject_rows_number = None
            )
        else:
            return WorksheetSettings(
        )
        """

    def testWorksheetSettings(self):
        """Test WorksheetSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.week_schedule import WeekSchedule  # noqa: E501

class TestWeekSchedule(unittest.TestCase):
    """WeekSchedule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WeekSchedule:
        """Test WeekSchedule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WeekSchedule`
        """
        model = WeekSchedule()  # noqa: E501
        if include_optional:
            return WeekSchedule(
                var_date = '',
                datetime = '',
                year_range = None,
                subjects = [
                    schedule_service_client.models.subject.Subject(
                        name = '', 
                        auditory = '', 
                        teacher = '', 
                        lesson = schedule_service_client.models.lesson.Lesson(
                            topic = 56, 
                            lesson = 56, 
                            type = '', ), )
                    ],
                coordinates = None
            )
        else:
            return WeekSchedule(
                coordinates = None,
        )
        """

    def testWeekSchedule(self):
        """Test WeekSchedule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.validation_error_loc_inner import ValidationErrorLocInner  # noqa: E501

class TestValidationErrorLocInner(unittest.TestCase):
    """ValidationErrorLocInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ValidationErrorLocInner:
        """Test ValidationErrorLocInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ValidationErrorLocInner`
        """
        model = ValidationErrorLocInner()  # noqa: E501
        if include_optional:
            return ValidationErrorLocInner(
            )
        else:
            return ValidationErrorLocInner(
        )
        """

    def testValidationErrorLocInner(self):
        """Test ValidationErrorLocInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from schedule_service_client.api.schedule_api import ScheduleApi
from schedule_service_client.api.workbook_api import WorkbookApi

# import ApiClient
from schedule_service_client.api_response import ApiResponse
from schedule_service_client.api_client import ApiClient
from schedule_service_client.configuration import Configuration
from schedule_service_client.exceptions import OpenApiException
from schedule_service_client.exceptions import ApiTypeError
from schedule_service_client.exceptions import ApiValueError
from schedule_service_client.exceptions import ApiKeyError
from schedule_service_client.exceptions import ApiAttributeError
from schedule_service_client.exceptions import ApiException

# import models into sdk package
from schedule_service_client.models.http_validation_error import HTTPValidationError
from schedule_service_client.models.lesson import Lesson
from schedule_service_client.models.schedule_result import ScheduleResult
from schedule_service_client.models.shape import Shape
from schedule_service_client.models.subject import Subject
from schedule_service_client.models.validation_error import ValidationError
from schedule_service_client.models.validation_error_loc_inner import ValidationErrorLocInner
from schedule_service_client.models.week_schedule import WeekSchedule
from schedule_service_client.models.week_schedule_result import WeekScheduleResult
from schedule_service_client.models.workbook_file import WorkbookFile
from schedule_service_client.models.worksheet_settings import WorksheetSettings



# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel
from schedule_service_client.models.shape import Shape
from typing import Dict, Any
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class WorksheetSettings(BaseModel):
    """
    WorksheetSettings
    """
    day_range: Optional[Shape] = None
    year_range: Optional[Shape] = None
    days_in_week_column_number: Optional[Any] = None
    platoon_column_number: Optional[Any] = None
    subject_rows_number: Optional[Any] = None
    __properties: ClassVar[List[str]] = ["day_range", "year_range", "days_in_week_column_number", "platoon_column_number", "subject_rows_number"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WorksheetSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of day_range
        if self.day_range:
            _dict['day_range'] = self.day_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of year_range
        if self.year_range:
            _dict['year_range'] = self.year_range.to_dict()
        # set to None if days_in_week_column_number (nullable) is None
        # and model_fields_set contains the field
        if self.days_in_week_column_number is None and "days_in_week_column_number" in self.model_fields_set:
            _dict['days_in_week_column_number'] = None

        # set to None if platoon_column_number (nullable) is None
        # and model_fields_set contains the field
        if self.platoon_column_number is None and "platoon_column_number" in self.model_fields_set:
            _dict['platoon_column_number'] = None

        # set to None if subject_rows_number (nullable) is None
        # and model_fields_set contains the field
        if self.subject_rows_number is None and "subject_rows_number" in self.model_fields_set:
            _dict['subject_rows_number'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        """Create an instance of WorksheetSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "day_range": Shape.from_dict(obj.get("day_range")) if obj.get("day_range") is not None else None,
            "year_range": Shape.from_dict(obj.get("year_range")) if obj.get("year_range") is not None else None,
            "days_in_week_column_number": obj.get("days_in_week_column_number"),
            "platoon_column_number": obj.get("platoon_column_number"),
            "subject_rows_number": obj.get("subject_rows_number")
        })
        return _obj


